pub enum MacOsOptionAsAlt {
OnlyLeft,
OnlyRight,
Both,
None,
}Expand description
macOS specific configuration for how the Option key is treated
macOS allows altering the way Option and Alt keys so Alt is treated as a modifier key rather than in character compose key. This is a proxy for winit’s OptionAsAlt.
Variants