pub struct WindowState { /* private fields */ }Expand description
Encapsulates and owns the global state of the application,
Implementations
Sourceimpl WindowState
impl WindowState
pub fn new(root_view_id: ViewId, os_theme: Option<Theme>) -> Self
Sourcepub fn remove_view(&mut self, id: ViewId)
pub fn remove_view(&mut self, id: ViewId)
This removes a view from the app state.
pub fn is_hovered(&self, id: &ViewId) -> bool
pub fn is_focused(&self, id: &ViewId) -> bool
pub fn is_active(&self, id: &ViewId) -> bool
pub fn is_clicking(&self, id: &ViewId) -> bool
pub fn is_dark_mode(&self) -> bool
pub fn is_file_hover(&self, id: &ViewId) -> bool
pub fn is_dragging(&self) -> bool
pub fn set_root_size(&mut self, size: Size)
Sourcepub fn register_fixed_element(&mut self, id: ViewId)
pub fn register_fixed_element(&mut self, id: ViewId)
Register a view as having fixed positioning. Called when a view’s style sets IsFixed to true.
Sourcepub fn unregister_fixed_element(&mut self, id: ViewId)
pub fn unregister_fixed_element(&mut self, id: ViewId)
Unregister a view from fixed positioning. Called when a view’s style sets IsFixed to false.
pub fn compute_layout(&mut self)
Sourcepub fn schedule_style(&mut self, id: ViewId)
pub fn schedule_style(&mut self, id: ViewId)
Requests that the style pass will run for id on the next frame, and ensures new frame is
scheduled to happen.
Sourcepub fn schedule_layout(&mut self, id: ViewId)
pub fn schedule_layout(&mut self, id: ViewId)
Requests that the layout pass will run for id on the next frame, and ensures new frame is
scheduled to happen.
Sourcepub fn schedule_paint(&mut self, id: ViewId)
pub fn schedule_paint(&mut self, id: ViewId)
Requests that the paint pass will run for id on the next frame, and ensures new frame is
scheduled to happen.
Sourcepub fn request_compute_layout_recursive(&mut self, _id: ViewId)
pub fn request_compute_layout_recursive(&mut self, _id: ViewId)
Requests that compute_layout will run for _id and all direct and indirect children.
pub fn request_paint(&mut self, _id: ViewId)